@@ -73,20 +73,20 @@ void CollectionModelPrivate::collectionChanged( const Akonadi::Collection &colle
     CollectionFetchJob *job = new CollectionFetchJob( newParent, CollectionFetchJob::Recursive, session );
     job->fetchScope().setIncludeUnsubscribed( unsubscribed );
     job->fetchScope().setIncludeStatistics( fetchStatistics );
-    q->connect( job, SIGNAL( collectionsReceived( const Akonadi::Collection::List& ) ),
-                q, SLOT( collectionsChanged( const Akonadi::Collection::List& ) ) );
-    q->connect( job, SIGNAL( result( KJob* ) ),
-                 q, SLOT( listDone( KJob* ) ) );
+    q->connect( job, SIGNAL(collectionsReceived(Akonadi::Collection::List)),
+                q, SLOT(collectionsChanged(Akonadi::Collection::List)) );
+    q->connect( job, SIGNAL(result(KJob*)),
+                 q, SLOT(listDone(KJob*)) );
 
   }
   else { // It's a simple change
     CollectionFetchJob *job = new CollectionFetchJob( collection, CollectionFetchJob::Base, session );
     job->fetchScope().setIncludeUnsubscribed( unsubscribed );
     job->fetchScope().setIncludeStatistics( fetchStatistics );
-    q->connect( job, SIGNAL( collectionsReceived( const Akonadi::Collection::List& ) ),
-                q, SLOT( collectionsChanged( const Akonadi::Collection::List& ) ) );
-    q->connect( job, SIGNAL( result( KJob* ) ),
-                 q, SLOT( listDone( KJob* ) ) );
+    q->connect( job, SIGNAL(collectionsReceived(Akonadi::Collection::List)),
+                q, SLOT(collectionsChanged(Akonadi::Collection::List)) );
+    q->connect( job, SIGNAL(result(KJob*)),
+                 q, SLOT(listDone(KJob*)) );
   }
 
 }
@@ -171,7 +171,7 @@ void CollectionModelPrivate::collectionsChanged( const Collection::List &cols )
   {
     lastSize = currentSize;
 
-    QMutableHashIterator< Collection::Id, QList< Collection::Id > > i( m_newChildCollections );
+    QMutableHashIterator< Collection::Id, QVector< Collection::Id > > i( m_newChildCollections );
     while ( i.hasNext() )
     {
       i.next();
@@ -180,7 +180,7 @@ void CollectionModelPrivate::collectionsChanged( const Collection::List &cols )
       // but that will be handled later.
       Collection::Id colId = i.key();
 
-      QList< Collection::Id > newChildCols = i.value();
+      QVector< Collection::Id > newChildCols = i.value();
       int newChildCount = newChildCols.size();
 //       if ( newChildCount == 0 )
 //       {
@@ -238,7 +238,7 @@ QModelIndex CollectionModelPrivate::indexForId( Collection::Id id, int column )
   if ( parentId != Collection::root().id() && !collections.contains( parentId ) )
     return QModelIndex();
 
-  QList<Collection::Id> list = childCollections.value( parentId );
+  QVector<Collection::Id> list = childCollections.value( parentId );
   int row = list.indexOf( id );
 
   if ( row >= 0 )
@@ -249,7 +249,7 @@ QModelIndex CollectionModelPrivate::indexForId( Collection::Id id, int column )
 bool CollectionModelPrivate::removeRowFromModel( int row, const QModelIndex & parent )
 {
   Q_Q( CollectionModel );
-  QList<Collection::Id> list;
+  QVector<Collection::Id> list;
   Collection parentCol;
   if ( parent.isValid() ) {
     parentCol = collections.value( parent.internalId() );
@@ -265,7 +265,8 @@ bool CollectionModelPrivate::removeRowFromModel( int row, const QModelIndex & pa
   }
 
   q->beginRemoveRows( parent, row, row );
-  Collection::Id delColId = list.takeAt( row );
+  const Collection::Id delColId = list[row];
+  list.remove( row );
   foreach ( Collection::Id childColId, childCollections[ delColId ] )
     collections.remove( childColId );
   collections.remove( delColId );
@@ -296,7 +297,7 @@ void CollectionModelPrivate::init()
 
   session = new Session( QCoreApplication::instance()->applicationName().toUtf8()
       + QByteArray( "-CollectionModel-" ) + QByteArray::number( qrand() ), q );
-  QTimer::singleShot( 0, q, SLOT( startFirstListJob() ) );
+  QTimer::singleShot( 0, q, SLOT(startFirstListJob()) );
 
   // monitor collection changes
   monitor = new Monitor();
@@ -308,14 +309,14 @@ void CollectionModelPrivate::init()
   KIconLoader::global()->addAppDir( QLatin1String( "kdepim" ) );
 
   // monitor collection changes
-  q->connect( monitor, SIGNAL( collectionChanged( const Akonadi::Collection& ) ),
-              q, SLOT( collectionChanged( const Akonadi::Collection& ) ) );
-  q->connect( monitor, SIGNAL( collectionAdded( const Akonadi::Collection&, const Akonadi::Collection& ) ),
-              q, SLOT( collectionChanged( const Akonadi::Collection& ) ) );
-  q->connect( monitor, SIGNAL( collectionRemoved( const Akonadi::Collection& ) ),
-              q, SLOT( collectionRemoved( const Akonadi::Collection& ) ) );
-  q->connect( monitor, SIGNAL( collectionStatisticsChanged( Akonadi::Collection::Id, const Akonadi::CollectionStatistics& ) ),
-              q, SLOT( collectionStatisticsChanged( Akonadi::Collection::Id, const Akonadi::CollectionStatistics& ) ) );
+  q->connect( monitor, SIGNAL(collectionChanged(Akonadi::Collection)),
+              q, SLOT(collectionChanged(Akonadi::Collection)) );
+  q->connect( monitor, SIGNAL(collectionAdded(Akonadi::Collection,Akonadi::Collection)),
+              q, SLOT(collectionChanged(Akonadi::Collection)) );
+  q->connect( monitor, SIGNAL(collectionRemoved(Akonadi::Collection)),
+              q, SLOT(collectionRemoved(Akonadi::Collection)) );
+  q->connect( monitor, SIGNAL(collectionStatisticsChanged(Akonadi::Collection::Id,Akonadi::CollectionStatistics)),
+              q, SLOT(collectionStatisticsChanged(Akonadi::Collection::Id,Akonadi::CollectionStatistics)) );
 }
 
 void CollectionModelPrivate::startFirstListJob()
@@ -326,9 +327,9 @@ void CollectionModelPrivate::startFirstListJob()
   CollectionFetchJob *job = new CollectionFetchJob( Collection::root(), CollectionFetchJob::Recursive, session );
   job->fetchScope().setIncludeUnsubscribed( unsubscribed );
   job->fetchScope().setIncludeStatistics( fetchStatistics );
-  q->connect( job, SIGNAL( collectionsReceived( const Akonadi::Collection::List& ) ),
-              q, SLOT( collectionsChanged( const Akonadi::Collection::List& ) ) );
-  q->connect( job, SIGNAL( result( KJob* ) ), q, SLOT( listDone( KJob* ) ) );
+  q->connect( job, SIGNAL(collectionsReceived(Akonadi::Collection::List)),
+              q, SLOT(collectionsChanged(Akonadi::Collection::List)) );
+  q->connect( job, SIGNAL(result(KJob*)), q, SLOT(listDone(KJob*)) );
 }
 
 //@endcond
