@@ -50,7 +50,7 @@ ContactSearchJob::ContactSearchJob( QObject * parent )
                                           "</request>"
 #else
                                           "prefix nco:<http://www.semanticdesktop.org/ontologies/2007/03/22/nco#>"
-                                          "SELECT ?r WHERE { ?r a nco:PersonContact }"
+                                          "SELECT ?r WHERE { ?r a nco:Contact }"
 #endif
                                         ) );
 }
@@ -111,11 +111,11 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?r ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:PersonContact . "
+          "    ?r a nco:Contact . "
           "    ?r nco:fullname \"%1\"^^<http://www.w3.org/2001/XMLSchema#string>. "
-          "  } "
+          "  "
           "} "
 #endif
       );
@@ -139,12 +139,12 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?person ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "   "
           "    ?person <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?person a nco:PersonContact ; "
+          "    ?person a nco:Contact ; "
           "            nco:hasEmailAddress ?email . "
           "    ?email nco:emailAddress \"%1\"^^<http://www.w3.org/2001/XMLSchema#string> . "
-          "  } "
+          "   "
           "}"
 #endif
       );
@@ -168,11 +168,11 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?r ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:PersonContact . "
+          "    ?r a nco:Contact . "
           "    ?r nco:nickname \"%1\"^^<http://www.w3.org/2001/XMLSchema#string> ."
-          "  } "
+          "  "
           "}"
 #endif
       );
@@ -210,9 +210,9 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?r ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:PersonContact . "
+          "    ?r a nco:Contact . "
           "    { ?r nco:fullname \"%1\"^^<http://www.w3.org/2001/XMLSchema#string>. } "
           "    UNION "
           "    { ?r nco:nameGiven \"%1\"^^<http://www.w3.org/2001/XMLSchema#string>. } "
@@ -221,7 +221,7 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "    UNION "
           "    { ?r nco:hasEmailAddress ?email . "
           "      ?email nco:emailAddress \"%1\"^^<http://www.w3.org/2001/XMLSchema#string> . } "
-          "  } "
+          "  "
           "}"
 #endif
       );
@@ -245,11 +245,11 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?r ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:PersonContact . "
+          "    ?r a nco:Contact . "
           "    ?r nco:contactUID \"%1\"^^<http://www.w3.org/2001/XMLSchema#string> ."
-          "  } "
+          "   "
           "}"
 #endif
       );
@@ -275,12 +275,12 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?r ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:PersonContact . "
+          "    ?r a nco:Contact . "
           "    ?r nco:fullname ?v . "
           "    ?v bif:contains \"'%1*'\" . "
-          "  } "
+          "  "
           "} "
 #endif
       );
@@ -304,13 +304,13 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?person ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "   "
           "    ?person <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?person a nco:PersonContact ; "
+          "    ?person a nco:Contact ; "
           "            nco:hasEmailAddress ?email . "
           "    ?email nco:emailAddress ?v . "
           "    FILTER regex(str(?v), \"^%1\", \"i\") "
-          "  } "
+          "  "
           "}"
 #endif
       );
@@ -334,12 +334,12 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?r ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:PersonContact . "
+          "    ?r a nco:Contact . "
           "    ?r nco:nickname ?v . "
           "    FILTER regex(str(?v), \"^%1\", \"i\") "
-          "  } "
+          "  "
           "}"
 #endif
       );
@@ -377,9 +377,9 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?r ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:PersonContact . "
+          "    ?r a nco:Contact . "
           "    { ?r nco:fullname ?v . "
           "      FILTER regex(str(?v), \"^%1\", \"i\") } "
           "    UNION "
@@ -392,7 +392,7 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "    { ?r nco:hasEmailAddress ?email . "
           "      ?email nco:emailAddress ?v . "
           "      FILTER regex(str(?v), \"^%1\", \"i\") } "
-          "  } "
+          "  "
           "}"
 #endif
       );
@@ -416,12 +416,12 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?r ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "  "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:PersonContact . "
+          "    ?r a nco:Contact . "
           "    ?r nco:contactUID ?v . "
           "    ?v bif:contains \"'%1*'\" . "
-          "  } "
+          " "
           "}"
 #endif
       );
@@ -447,12 +447,12 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?r ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "  "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:PersonContact . "
+          "    ?r a nco:Contact . "
           "    ?r nco:fullname ?v . "
           "%1"
-          "  } "
+          "  "
           "} "
 #endif
       );
@@ -477,13 +477,13 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?person ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "  "
           "    ?person <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?person a nco:PersonContact ; "
+          "    ?person a nco:Contact ; "
           "            nco:hasEmailAddress ?email . "
           "    ?email nco:emailAddress ?v . "
           "%1"
-          "  } "
+          "  "
           "}"
 #endif
       );
@@ -508,12 +508,12 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?r ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "  "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:PersonContact . "
+          "    ?r a nco:Contact . "
           "    ?r nco:nickname ?v . "
           "%1"
-          "  } "
+          "  "
           "}"
 #endif
       );
@@ -552,9 +552,9 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?r ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "  "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:PersonContact . "
+          "    ?r a nco:Contact . "
           "    { ?r nco:fullname ?v . "
           "%1 }"
           "    UNION "
@@ -567,7 +567,7 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "    { ?r nco:hasEmailAddress ?email . "
           "      ?email nco:emailAddress ?v . "
           "%1 }"
-          "  } "
+          " "
           "}"
 #endif
       );
@@ -580,7 +580,7 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "    <and>"
           "      <equals>"
           "        <field name=\"type\"/>"
-          "        <string>PersonContact</string>"
+          "        <string>Contact</string>"
           "      </equals>"
           "      <contains>"
           "        <field name=\"contactUID\"/>"
@@ -592,12 +592,12 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
 #else
           "SELECT DISTINCT ?r ?reqProp1 "
           "WHERE { "
-          "  graph ?g { "
+          "  "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:PersonContact . "
+          "    ?r a nco:Contact . "
           "    ?r nco:contactUID ?v . "
           "    ?v bif:contains \"'%1'\" . "
-          "  } "
+          " "
           "}"
 #endif
       );
