@@ -21,6 +21,8 @@
 
 #include "addresseditwidget.h"
 
+#include "autoqpointer_p.h"
+
 #include <QtCore/QEvent>
 #include <QtCore/QList>
 #include <QtGui/QApplication>
@@ -45,6 +47,15 @@
 #include <kseparator.h>
 #include <ktextedit.h>
 
+#include <functional>
+
+struct LocaleAwareLessThan : std::binary_function<QString,QString,bool> {
+  bool operator()( const QString &s1, const QString &s2 ) const
+  {
+    return QString::localeAwareCompare( s1, s2 ) < 0 ;
+  }
+};
+
 class TabPressEater : public QObject
 {
   public:
@@ -93,7 +104,7 @@ class AddressTypeDialog : public KDialog
 AddressSelectionWidget::AddressSelectionWidget( QWidget *parent )
   : KComboBox( parent )
 {
-  connect( this, SIGNAL( activated( int ) ), SLOT( selected( int ) ) );
+  connect( this, SIGNAL(activated(int)), SLOT(selected(int)) );
 }
 
 AddressSelectionWidget::~AddressSelectionWidget()
@@ -147,8 +158,8 @@ AddressTypeCombo::AddressTypeCombo( QWidget *parent )
 
   update();
 
-  connect( this, SIGNAL( activated( int ) ),
-           this, SLOT( selected( int ) ) );
+  connect( this, SIGNAL(activated(int)),
+           this, SLOT(selected(int)) );
 }
 
 AddressTypeCombo::~AddressTypeCombo()
@@ -201,9 +212,9 @@ void AddressTypeCombo::selected( int pos )
 
 void AddressTypeCombo::otherSelected()
 {
-  AddressTypeDialog dlg( mType, this );
-  if ( dlg.exec() ) {
-    mType = dlg.type();
+  AutoQPointer<AddressTypeDialog> dlg = new AddressTypeDialog( mType, this );
+  if ( dlg->exec() ) {
+    mType = dlg->type();
     if ( !mTypeList.contains( mType ) )
       mTypeList.insert( mTypeList.at( mTypeList.count() - 1 ), mType );
   } else {
@@ -218,13 +229,12 @@ AddressEditWidget::AddressEditWidget( QWidget *parent )
   : QWidget( parent ), mReadOnly( false )
 {
   QGridLayout *layout = new QGridLayout( this );
-  layout->setSpacing( 2 );
-  layout->setMargin( 4 );
   layout->setSpacing( KDialog::spacingHint() );
+  layout->setMargin( 0 );
 
   mAddressSelectionWidget = new AddressSelectionWidget( this );
-  connect( mAddressSelectionWidget, SIGNAL( selectionChanged( const KABC::Address& ) ),
-           SLOT( updateAddressView() ) );
+  connect( mAddressSelectionWidget, SIGNAL(selectionChanged(KABC::Address)),
+           SLOT(updateAddressView()) );
   layout->addWidget( mAddressSelectionWidget, 0, 0, 1, 3 );
 
   mAddressView = new QLabel( this );
@@ -236,11 +246,11 @@ AddressEditWidget::AddressEditWidget( QWidget *parent )
   layout->addWidget( mAddressView, 1, 0, 1, 3 );
 
   mCreateButton = new QPushButton( i18nc( "street/postal", "New..." ), this );
-  connect( mCreateButton, SIGNAL( clicked() ), this, SLOT( createAddress() ) );
+  connect( mCreateButton, SIGNAL(clicked()), this, SLOT(createAddress()) );
   mEditButton = new QPushButton( i18nc( "street/postal", "Edit..." ), this );
-  connect( mEditButton, SIGNAL( clicked() ), this, SLOT( editAddress() ) );
+  connect( mEditButton, SIGNAL(clicked()), this, SLOT(editAddress()) );
   mDeleteButton = new QPushButton( i18nc( "street/postal", "Delete" ), this );
-  connect( mDeleteButton, SIGNAL( clicked() ), this, SLOT( deleteAddress() ) );
+  connect( mDeleteButton, SIGNAL(clicked()), this, SLOT(deleteAddress()) );
 
   layout->addWidget( mCreateButton, 2, 0 );
   layout->addWidget( mEditButton, 2, 1 );
@@ -267,9 +277,9 @@ void AddressEditWidget::updateName( const QString &name )
 
 void AddressEditWidget::createAddress()
 {
-  AddressEditDialog dialog( this );
-  if ( dialog.exec() ) {
-    const KABC::Address address = dialog.address();
+  AutoQPointer<AddressEditDialog> dialog = new AddressEditDialog( this );
+  if ( dialog->exec() ) {
+    const KABC::Address address = dialog->address();
     fixPreferredAddress( address );
     mAddressList.append( address );
     mAddressSelectionWidget->setAddresses( mAddressList );
@@ -282,10 +292,10 @@ void AddressEditWidget::createAddress()
 
 void AddressEditWidget::editAddress()
 {
-  AddressEditDialog dialog( this );
-  dialog.setAddress( mAddressSelectionWidget->currentAddress() );
-  if ( dialog.exec() ) {
-    const KABC::Address address = dialog.address();
+  AutoQPointer<AddressEditDialog> dialog = new AddressEditDialog( this );
+  dialog->setAddress( mAddressSelectionWidget->currentAddress() );
+  if ( dialog->exec() ) {
+    const KABC::Address address = dialog->address();
     fixPreferredAddress( address );
     mAddressList[ mAddressSelectionWidget->currentIndex() ] = address;
     mAddressSelectionWidget->setAddresses( mAddressList );
@@ -433,7 +443,7 @@ AddressEditDialog::AddressEditDialog( QWidget *parent )
 
   QPushButton *labelButton = new QPushButton( i18n( "Edit Label..." ), page );
   topLayout->addWidget( labelButton, 7, 0, 1, 2 );
-  connect( labelButton, SIGNAL( clicked() ), SLOT( editLabel() ) );
+  connect( labelButton, SIGNAL(clicked()), SLOT(editLabel()) );
 
   fillCountryCombo();
   label->setBuddy( mCountryCombo );
@@ -466,7 +476,7 @@ void AddressEditDialog::editLabel()
     mLabel = result;
 }
 
-void AddressEditDialog::setAddress(const KABC::Address &address)
+void AddressEditDialog::setAddress( const KABC::Address &address )
 {
   mAddress = address;
 
@@ -513,15 +523,18 @@ void AddressEditDialog::fillCountryCombo()
 {
   QStringList countries;
 
-  foreach( const QString &cc, KGlobal::locale()->allCountriesList() ) {
-    countries.append( KGlobal::locale()->countryCodeToName(cc) );
-  }
+  foreach ( const QString &cc, KGlobal::locale()->allCountriesList() )
+    countries.append( KGlobal::locale()->countryCodeToName( cc ) );
 
-  countries = sortLocaleAware( countries );
+  qSort( countries.begin(), countries.end(), LocaleAwareLessThan() );
 
   mCountryCombo->addItems( countries );
-  mCountryCombo->completionObject()->setItems( countries );
   mCountryCombo->setAutoCompletion( true );
+  mCountryCombo->completionObject()->setItems( countries );
+  mCountryCombo->completionObject()->setIgnoreCase( true );
+
+  const QString currentCountry = KGlobal::locale()->countryCodeToName( KGlobal::locale()->country() );
+  mCountryCombo->setCurrentIndex( mCountryCombo->findText( currentCountry ) );
 }
 
 
@@ -578,41 +591,4 @@ KABC::Address::Type AddressTypeDialog::type() const
   return type;
 }
 
-/**
-  Small helper class, I hope we can remove it as soon as a general solution has
-  been committed to kdelibs
- */
-class LocaleAwareString : public QString
-{
-  public:
-    LocaleAwareString() : QString()
-    {}
-
-    LocaleAwareString( const QString &str ) : QString( str )
-    {}
-};
-
-static bool operator<( const LocaleAwareString &s1, const LocaleAwareString &s2 )
-{
-  return ( QString::localeAwareCompare( s1, s2 ) < 0 );
-}
-
-QStringList AddressEditDialog::sortLocaleAware( const QStringList &list )
-{
-  QList<LocaleAwareString> sortedList;
-
-  QStringList::ConstIterator it;
-  for ( it = list.constBegin(); it != list.constEnd(); ++it )
-    sortedList.append( LocaleAwareString( *it ) );
-
-  qSort( sortedList.begin(), sortedList.end() );
-
-  QStringList retval;
-  QList<LocaleAwareString>::ConstIterator retIt;
-  for ( retIt = sortedList.constBegin(); retIt != sortedList.constEnd(); ++retIt )
-    retval.append( *retIt );
-
-  return retval;
-}
-
 #include "addresseditwidget.moc"
