@@ -20,6 +20,7 @@
 #include "localfolderstest.h"
 
 #include "../../collectionpathresolver_p.h"
+#include "../../dbusconnectionpool.h"
 #include "../specialmailcollectionssettings.h"
 
 #include <QDBusConnectionInterface>
@@ -89,13 +90,13 @@ void LocalFoldersTest::testLock()
   const QString dbusName = QString::fromLatin1( "org.kde.pim.SpecialCollections" );
 
   // Initially not locked.
-  QVERIFY( !QDBusConnection::sessionBus().interface()->isServiceRegistered( dbusName ) );
+  QVERIFY( !DBusConnectionPool::threadConnection().interface()->isServiceRegistered( dbusName ) );
 
   // Get the lock.
   {
     GetLockJob *ljob = new GetLockJob( this );
     AKVERIFYEXEC( ljob );
-    QVERIFY( QDBusConnection::sessionBus().interface()->isServiceRegistered( dbusName ) );
+    QVERIFY( DBusConnectionPool::threadConnection().interface()->isServiceRegistered( dbusName ) );
   }
 
   // Getting the lock again should fail.
@@ -105,9 +106,9 @@ void LocalFoldersTest::testLock()
   }
 
   // Release the lock.
-  QVERIFY( QDBusConnection::sessionBus().interface()->isServiceRegistered( dbusName ) );
+  QVERIFY( DBusConnectionPool::threadConnection().interface()->isServiceRegistered( dbusName ) );
   releaseLock();
-  QVERIFY( !QDBusConnection::sessionBus().interface()->isServiceRegistered( dbusName ) );
+  QVERIFY( !DBusConnectionPool::threadConnection().interface()->isServiceRegistered( dbusName ) );
 }
 
 void LocalFoldersTest::testInitialState()
@@ -342,7 +343,7 @@ void LocalFoldersTest::testBatchRegister()
   SpecialMailCollectionsTesting *smct = SpecialMailCollectionsTesting::_t_self();
   Q_ASSERT( smc );
   Q_ASSERT( smct );
-  QSignalSpy spy( smc, SIGNAL(collectionsChanged(const Akonadi::AgentInstance&)) );
+  QSignalSpy spy( smc, SIGNAL(collectionsChanged(Akonadi::AgentInstance)) );
   QSignalSpy defSpy( smc, SIGNAL(defaultCollectionsChanged()) );
   QVERIFY( spy.isValid() );
   QVERIFY( defSpy.isValid() );
@@ -504,7 +505,7 @@ void LocalFoldersTest::testDefaultResourceJob()
 
     QVariantMap options;
     options.insert( QLatin1String( "Name" ), i18nc( "local mail folder", "Local Folders" ) );
-    options.insert( QLatin1String( "Path" ), KGlobal::dirs()->localxdgdatadir() + QLatin1String( "local-mail" ) );
+    options.insert( QLatin1String( "Path" ), QString( KGlobal::dirs()->localxdgdatadir() + QLatin1String( "local-mail" ) ) );
     resjob->setDefaultResourceOptions( options );
     resjob->setTypes( mDisplayNameMap.keys() );
     resjob->setNameForTypeMap( mDisplayNameMap );
@@ -544,7 +545,7 @@ void LocalFoldersTest::testDefaultResourceJob()
 
     QVariantMap options;
     options.insert( QLatin1String( "Name" ), i18nc( "local mail folder", "Local Folders" ) );
-    options.insert( QLatin1String( "Path" ), KGlobal::dirs()->localxdgdatadir() + QLatin1String( "local-mail" ) );
+    options.insert( QLatin1String( "Path" ), QString( KGlobal::dirs()->localxdgdatadir() + QLatin1String( "local-mail" ) ) );
     resjob->setDefaultResourceOptions( options );
     resjob->setTypes( mDisplayNameMap.keys() );
     resjob->setNameForTypeMap( mDisplayNameMap );
@@ -585,7 +586,7 @@ void LocalFoldersTest::testRecoverDefaultResource()
 
     QVariantMap options;
     options.insert( QLatin1String( "Name" ), i18nc( "local mail folder", "Local Folders" ) );
-    options.insert( QLatin1String( "Path" ), KGlobal::dirs()->localxdgdatadir() + QLatin1String( "local-mail" ) );
+    options.insert( QLatin1String( "Path" ), QString(KGlobal::dirs()->localxdgdatadir() + QLatin1String( "local-mail" ) ) );
     resjob->setDefaultResourceOptions( options );
     resjob->setTypes( mDisplayNameMap.keys() );
     resjob->setNameForTypeMap( mDisplayNameMap );
