@@ -68,8 +68,13 @@ public:
 SelectionProxyModel::SelectionProxyModel( QItemSelectionModel *selectionModel, QObject *parent )
   : KSelectionProxyModel( selectionModel, parent ), d_ptr( new SelectionProxyModelPrivate( this ) )
 {
-  connect( this, SIGNAL( rootIndexAdded( const QModelIndex& ) ), SLOT( rootIndexAdded( const QModelIndex& ) ) );
-  connect( this, SIGNAL( rootIndexAboutToBeRemoved( const QModelIndex& ) ), SLOT( rootIndexAboutToBeRemoved( const QModelIndex& ) ) );
+  connect( this, SIGNAL(rootIndexAdded(QModelIndex)), SLOT(rootIndexAdded(QModelIndex)) );
+  connect( this, SIGNAL(rootIndexAboutToBeRemoved(QModelIndex)), SLOT(rootIndexAboutToBeRemoved(QModelIndex)) );
+}
+
+SelectionProxyModel::~SelectionProxyModel()
+{
+  delete d_ptr;
 }
 
 #include "selectionproxymodel.moc"
