@@ -20,6 +20,9 @@
 
 #include "addresstest.h"
 #include "kabc/address.h"
+#include <kconfig.h>
+#include <kconfiggroup.h>
+#include "kstandarddirs.h"
 #include <qtest_kde.h>
 
 QTEST_KDEMAIN( AddressTest, NoGUI )
@@ -46,16 +49,16 @@ void AddressTest::storeTest()
   address.setCountry( QLatin1String( "My Country" ) );
   address.setLabel( QLatin1String( "My Label" ) );
 
-  QVERIFY( address.id() == QLatin1String( "My Id" ) );
-  QVERIFY( address.type() == KABC::Address::Home );
-  QVERIFY( address.postOfficeBox() == QLatin1String( "1234" ) );
-  QVERIFY( address.extended() == QLatin1String( "My Extended Label" ) );
-  QVERIFY( address.street() == QLatin1String( "My Street" ) );
-  QVERIFY( address.locality() == QLatin1String( "My Locality" ) );
-  QVERIFY( address.region() == QLatin1String( "My Region" ) );
-  QVERIFY( address.postalCode() == QLatin1String( "My PostalCode" ) );
-  QVERIFY( address.country() == QLatin1String( "My Country" ) );
-  QVERIFY( address.label() == QLatin1String( "My Label" ) );
+  QCOMPARE( address.id(), QLatin1String( "My Id" ) );
+  QCOMPARE( address.type(), KABC::Address::Home );
+  QCOMPARE( address.postOfficeBox(), QLatin1String( "1234" ) );
+  QCOMPARE( address.extended(), QLatin1String( "My Extended Label" ) );
+  QCOMPARE( address.street(), QLatin1String( "My Street" ) );
+  QCOMPARE( address.locality(), QLatin1String( "My Locality" ) );
+  QCOMPARE( address.region(), QLatin1String( "My Region" ) );
+  QCOMPARE( address.postalCode(), QLatin1String( "My PostalCode" ) );
+  QCOMPARE( address.country(), QLatin1String( "My Country" ) );
+  QCOMPARE( address.label(), QLatin1String( "My Label" ) );
 }
 
 void AddressTest::equalsTest()
@@ -142,15 +145,40 @@ void AddressTest::serializeTest()
 void AddressTest::formatTest()
 {
   {
+    // check availability of country to ISO code mapping data file  
+    const QString mapfile = KGlobal::dirs()->findResource( "data", QLatin1String( "kabc/countrytransl.map" ) );
+    QVERIFY2( !mapfile.isEmpty(), "Country to ISO code mapping data file does not exist" );
+    
+    QFileInfo fileInfo( mapfile );
+    QVERIFY2( fileInfo.exists(), "Country to ISO code mapping data file does not exist" );
+    QVERIFY2( fileInfo.isReadable(), "Country to ISO code mapping data file is not readable" );
+  }
+  
+  {
+    const QString templateFile = KStandardDirs::locate( "locale",
+        QLatin1String( "l10n/de/entry.desktop" ) );
+    QVERIFY2( !templateFile.isEmpty(), "Address format template file for 'de' does not exist" );
+    
+    const KConfig templateConfig( templateFile );
+    QVERIFY2( templateConfig.hasGroup( "KCM Locale" ),
+              "Address format config for 'de' is missing expected 'KCM Locale' group" );
+    const KConfigGroup templateGroup = templateConfig.group( "KCM Locale" );
+    QVERIFY2( templateGroup.hasKey( "AddressFormat" ),
+              "Address format config is missing expected key 'AddressFormat'" );
+    const QString addressTemplate = templateGroup.readEntry( "AddressFormat" );
+    QVERIFY2( !addressTemplate.isEmpty(),
+              "Address format template for 'de' is empty" );
+    
     KABC::Address address;
     address.setStreet( QLatin1String( "Lummerlandstr. 1" ) );
     address.setPostalCode( QLatin1String( "12345" ) );
     address.setLocality( QLatin1String( "Lummerstadt" ) );
     address.setCountry ( QLatin1String( "Germany" ) );
 
-    const QString result( QLatin1String( "Jim Knopf\nLummerlandstr. 1\n12345 Lummerstadt\n\nGERMANY" ) );
+    const QString result( QLatin1String( "Jim Knopf\nLummerlandstr. 1\n"
+                                         "12345 Lummerstadt\n\nGERMANY" ) );
 
-    QVERIFY( address.formattedAddress( QLatin1String( "Jim Knopf" ) ) == result );
+    QCOMPARE( address.formattedAddress( QLatin1String( "Jim Knopf" ) ), result );
   }
 
   {
@@ -162,8 +190,9 @@ void AddressTest::formatTest()
     address.setCountry( QLatin1String( "United States of America" ) );
 
     const QString result(
-      QLatin1String( "Huck Finn\n457 Foobar Ave\nNervousbreaktown,  DC 1A2B3C\n\nUNITED STATES OF AMERICA" ) );
-    QVERIFY( address.formattedAddress( QLatin1String( "Huck Finn" ) ) == result );
+      QLatin1String( "Huck Finn\n457 Foobar Ave\nNervousbreaktown,"
+                     "  DC 1A2B3C\n\nUNITED STATES OF AMERICA" ) );
+    QCOMPARE( address.formattedAddress( QLatin1String( "Huck Finn" ) ), result );
   }
 
   {
@@ -173,9 +202,10 @@ void AddressTest::formatTest()
     address.setLocality( QLatin1String( "Lummerstadt" ) );
     address.setCountry( QLatin1String( "Deutschland" ) );
 
-    const QString result( QLatin1String( "Jim Knopf\nLummerlandstr. 1\n12345 Lummerstadt\n\nDEUTSCHLAND" ) );
+    const QString result( QLatin1String( "Jim Knopf\nLummerlandstr. 1\n"
+                                         "12345 Lummerstadt\n\nDEUTSCHLAND" ) );
 
-    QVERIFY( address.formattedAddress( QLatin1String( "Jim Knopf" ) ) == result );
+    QCOMPARE( address.formattedAddress( QLatin1String( "Jim Knopf" ) ), result );
   }
 
   {
@@ -187,7 +217,7 @@ void AddressTest::formatTest()
 
     const QString result( QLatin1String( "Jim Knopf\nLummerlandstr. 1\nLummerstadt, 12345" ) );
 
-    QVERIFY( address.formattedAddress( QLatin1String( "Jim Knopf" ) ) == result );
+    QCOMPARE( address.formattedAddress( QLatin1String( "Jim Knopf" ) ), result );
   }
 }
 
