@@ -91,7 +91,7 @@ void HolidayParserDriverPlan::error( const QString &errorMessage )
 void HolidayParserDriverPlan::parse()
 {
     // Parse the file using every calendar system in the file
-    foreach( QString calendar, m_fileCalendarTypes ) {
+    foreach( const QString &calendar, m_fileCalendarTypes ) {
 
         // Cater for events defined in other Calendar Systems where request year could cover 2 or 3 event years
         // Perhaps also parse year before and year after to allow events to span years or shift to other year?
@@ -680,27 +680,33 @@ void HolidayParserDriverPlan::setEvent( int jd, int observeOffset, int duration
     // Date the holiday will be observed on
     int observeJd = jd + observeOffset;
 
-    // Create entries compatible with old parser for now
-    for ( int dd = 0; dd < duration; ++dd ) {
-
-        // Only set if event falls in requested date range
-        if ( m_parseCalendar->isValid( QDate::fromJulianDay( observeJd + dd ) ) &&
-             observeJd + dd >= m_requestStart.toJulianDay() &&
-             observeJd + dd <= m_requestEnd.toJulianDay() ) {
-
-            KHolidays::Holiday holiday;
-            holiday.d->mDate = QDate::fromJulianDay( observeJd + dd );
-            holiday.d->mText = m_eventName;
-            holiday.d->mShortText = m_eventName;
-            if ( m_eventColorName == 2 || m_eventColorName == 9 ||
-                m_eventColorDay == 2 || m_eventColorDay == 9 ) {
-                holiday.d->mDayType = KHolidays::Holiday::NonWorkday;
-            } else {
-                holiday.d->mDayType = KHolidays::Holiday::Workday;
-            }
-            m_resultList.append( holiday );
-
+    if ( m_multidayMode == Holiday::MultidayHolidaysAsSingleEvents ) {
+        addHoliday( QDate::fromJulianDay( observeJd ), duration );
+    } else { // KHolidays::MultidayHolidaysAsMultipleEvents
+        // Create backwards compatible holidays, one incidence per day
+        for ( int dd = 0; dd < duration; ++dd ) {
+            addHoliday( QDate::fromJulianDay( observeJd + dd ), 1 );
         }
+    }
+}
 
+void  HolidayParserDriverPlan::addHoliday( const QDate &observedDate, int duration )
+{
+    // Only set if event falls in requested date range, i.e. either starts or ends during range
+    if ( m_parseCalendar->isValid( observedDate ) &&
+         observedDate <= m_requestEnd &&
+         observedDate.addDays( duration - 1 ) >= m_requestStart ) {
+        KHolidays::Holiday holiday;
+        holiday.d->mObservedDate = observedDate;
+        holiday.d->mDuration = duration;
+        holiday.d->mText = m_eventName;
+        holiday.d->mShortText = m_eventName;
+        if ( m_eventColorName == 2 || m_eventColorName == 9 ||
+             m_eventColorDay == 2 || m_eventColorDay == 9 ) {
+            holiday.d->mDayType = KHolidays::Holiday::NonWorkday;
+        } else {
+            holiday.d->mDayType = KHolidays::Holiday::Workday;
+        }
+        m_resultList.append( holiday );
     }
 }
