@@ -199,6 +199,15 @@ namespace KPIMIdentities
        */
       void addImage( const QImage &image, const QString &imageName );
 
+
+      /**
+       * @brief setEnabledSignature
+       * @param enabled
+       * @since 4.9
+       */
+      void setEnabledSignature(bool enabled);
+      bool isEnabledSignature() const;
+
       /**
        * @since 4.3
        * @deprecated Use the other overload of insertIntoTextEdit() instead. This one doesn't
@@ -234,11 +243,18 @@ namespace KPIMIdentities
        * 
        * @since 4.4
        */
-      // TODO: KDE5: BIC: Reorder paramters, the order here is a workaround for ambiguous parameters
+      // TODO: KDE5: BIC: Reorder parameters, the order here is a workaround for ambiguous parameters
       //                  with the deprecated method
       void insertIntoTextEdit( Placement placement, AddedText addedText,
                                KPIMTextEdit::TextEdit *textEdit ) const;
 
+      /**
+       * @since 4.9
+       **/
+      //TODO; KDE5 merge with previous method
+      void insertIntoTextEdit( Placement placement, AddedText addedText,
+                               KPIMTextEdit::TextEdit *textEdit, bool forceDisplay ) const;
+
       /**
        * Inserts this given signature into the given text edit.
        * The cursor position is preserved.
@@ -273,6 +289,7 @@ namespace KPIMIdentities
       void readConfig( const KConfigGroup &config );
 
     private:
+      void insertSignatureText(Placement placement, AddedText addedText, KPIMTextEdit::TextEdit *textEdit, bool forceDisplay) const;
 
       // TODO: KDE5: BIC: Move all to private class
 
